==> ingdao-0.0.6.tar.gz: example/datasync/lib/datalayer/entity/tanktimesheet/tanktimesheet.dart <==
import 'package:ingdao/dataflow/entity/dfbaseentity.dart';
import 'package:ingdao/dataflow/entity/dfdbentity.dart';
import 'package:ingdao/dataflow/field/dfbasefield.dart';
import 'package:ingdao/dataflow/field/dfdbfield.dart';
import 'package:ingdao/dataflow/field/dffieldtype.dart';
import 'package:ingdao/dataflow/field/dfstringvalidator.dart';
import 'package:ingdao/dataflow/field/dfdatetimevalidator.dart';
import '../../field/tanktimesheet/tanktimesheet_field.dart';
import 'package:object_mapper/object_mapper.dart';

class TankTimesheet extends DfDbEntity with TankTimesheetField {

  String id;
  String tankId;
  String name;
  DateTime markOn;
  bool active;
    
  TankTimesheet ({String pId, String pTankId, String pName, DateTime pMarkOn, bool pActive}) : super(name: "tanktimesheet") {
    fId = DfDbField(entity: this, name: "id", primaryKey: true, joinKey: false, fieldType: DfFieldType.text(), getObjectValue: () => id, setObjectValue: (v) => id = v, value: pId);
    fTankId = DfDbField(entity: this, name: "tankid", primaryKey: false, joinKey: true, fieldType: DfFieldType.text(), getObjectValue: () => tankId, setObjectValue: (v) => tankId = v, value: pTankId);
    fName = DfDbField(entity: this, name: "name", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(strValidator: DfStringValidator(isAllowEmpty: false, minLen: 5, maxLen: 100, isAlphaAndSpaceAndDigitOnly: true)), getObjectValue: () => name, setObjectValue: (v) => name = v, value: pName);
    fMarkOn = DfDbField(entity: this, name: "markon", primaryKey: false, joinKey: false, fieldType: DfFieldType.datetime(dateTimeValidator: DfDateTimeValidator(isLtNowCheck: true)), getObjectValue: () => markOn, setObjectValue: (v) => markOn = v, value: pMarkOn);
    fActive = DfDbField(entity: this, name: "active", primaryKey: false, joinKey: false, fieldType: DfFieldType.boolean(), getObjectValue: () => active, setObjectValue: (v) => active = v, value: pActive);
    //fTankName = DfDbField(entity: Tank(), name: "name", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), displayOnly: true);
  }

  //Define the sqilite table fields available.
  //Define the fields will map back to the sqlite query executed reuslt: Map<String,dynamic>
  @override
  List<DfDbField> fields() {
     return [fId,fTankId,fName,fMarkOn,fActive/*,fTankName*/];
  }

  @override
  DfBaseEntity<DfBaseField> newInstance() {
    return TankTimesheet();
  }

  @override
  DfBaseEntity<DfDbField> jsonToObject(Mapper map) {
    return map.toObject<TankTimesheet>();
  }
}

==> ingdao-0.0.10.tar.gz: example/datasync/lib/datalayer/entity/tanktimesheet/tanktimesheet.dart <==
import 'package:ingdao/dataflow/entity/dfbaseentity.dart';
import 'package:ingdao/dataflow/entity/dfdbentity.dart';
import 'package:ingdao/dataflow/field/dfbasefield.dart';
import 'package:ingdao/dataflow/field/dfdbfield.dart';
import 'package:ingdao/dataflow/field/dffieldtype.dart';
import 'package:ingdao/dataflow/control/dfquery.dart';
import 'package:ingdao/dataflow/field/dfstringvalidator.dart';
import 'package:ingdao/dataflow/field/dfdatetimevalidator.dart';
import '../../field/tanktimesheet/tanktimesheet_field.dart';
import 'package:object_mapper/object_mapper.dart';

class TankTimesheet extends DfDbEntity with TankTimesheetField {

  String id;
  String tankId;
  String name;
  DateTime markOn;
  bool active;
    
  TankTimesheet ({String pId, String pTankId, String pName, DateTime pMarkOn, bool pActive}) : super(name: "tanktimesheet") {
    fId = DfDbField(entity: this, name: "id", primaryKey: true, joinKey: false, fieldType: DfFieldType.text(), getObjectValue: () => id, setObjectValue: (v) => id = v, value: pId);
    fTankId = DfDbField(entity: this, name: "tankid", primaryKey: false, joinKey: true, fieldType: DfFieldType.text(), getObjectValue: () => tankId, setObjectValue: (v) => tankId = v, value: pTankId);
    fName = DfDbField(entity: this, name: "name", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(strValidator: DfStringValidator(isAllowEmpty: false, minLen: 5, maxLen: 100, isAlphaAndSpaceAndDigitOnly: true)), getObjectValue: () => name, setObjectValue: (v) => name = v, value: pName);
    fMarkOn = DfDbField(entity: this, name: "markon", primaryKey: false, joinKey: false, fieldType: DfFieldType.datetime(dateTimeValidator: DfDateTimeValidator(isLtNowCheck: true)), getObjectValue: () => markOn, setObjectValue: (v) => markOn = v, value: pMarkOn);
    fActive = DfDbField(entity: this, name: "active", primaryKey: false, joinKey: false, fieldType: DfFieldType.boolean(), getObjectValue: () => active, setObjectValue: (v) => active = v, value: pActive);
    //fTankName = DfDbField(entity: Tank(), name: "name", primaryKey: false, joinKey: false, fieldType: DfFieldType.text(), displayOnly: true);
  }

  //Define the sqilite table fields available.
  //Define the fields will map back to the sqlite query executed reuslt: Map<String,dynamic>
  @override
  List<DfDbField> fields() {
     return [fId,fTankId,fName,fMarkOn,fActive/*,fTankName*/];
  }

  @override
  DfBaseEntity<DfBaseField> newInstance() {
    return TankTimesheet();
  }

  @override
  DfBaseEntity<DfDbField> jsonToObject(DfQueryPurpose purpose, Mapper map) {
    return map.toObject<TankTimesheet>();
  }
}
